from typing import FrozenSet

empty_tags: FrozenSet[str]
deprecated_tags: FrozenSet[str]
link_attrs: FrozenSet[str]
event_attrs: FrozenSet[str]
safe_attrs: FrozenSet[str]
top_level_tags: FrozenSet[str]
head_tags: FrozenSet[str]
general_block_tags: FrozenSet[str]
list_tags: FrozenSet[str]
table_tags: FrozenSet[str]
block_tags: FrozenSet[str]
form_tags: FrozenSet[str]
special_inline_tags: FrozenSet[str]
phrase_tags: FrozenSet[str]
font_style_tags: FrozenSet[str]
frame_tags: FrozenSet[str]
html5_tags: FrozenSet[str]
nonstandard_tags: FrozenSet[str]
tags: FrozenSet[str]
